/*-
 * ============LICENSE_START=======================================================
 * ECOMP-REST
 * ================================================================================
 * Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
 * ================================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ============LICENSE_END=========================================================
 */

package org.openecomp.policy.rest.jpa;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQuery;
import javax.persistence.OrderBy;
import javax.persistence.PrePersist;
import javax.persistence.PreUpdate;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Transient;

import org.openecomp.policy.common.logging.eelf.MessageCodes;
import org.openecomp.policy.common.logging.eelf.PolicyLogger;
import org.openecomp.policy.rest.XacmlAdminAuthorization;


@Entity
@Table(name="DecisionSettings")
@NamedQuery(name="DecisionSettings.findAll", query="SELECT a FROM DecisionSettings a order by  a.priority asc, a.xacmlId asc")
public class DecisionSettings implements Serializable {
	private static final long serialVersionUID = 1L;

	@Id
	@GeneratedValue(strategy = GenerationType.AUTO)
	@Column(name="id")
	private int id;

	@Temporal(TemporalType.TIMESTAMP)
	@Column(name="created_date", updatable=false)
	private Date createdDate;

	@Column(name="description", nullable=true, length=2048)
	private String description;

	@Temporal(TemporalType.TIMESTAMP)
	@Column(name="modified_date", nullable=false)
	private Date modifiedDate;

	@Column(name="PRIORITY", nullable=true)
	@OrderBy("asc")
	private String priority;
	
	@Column(name="xacml_id", unique = true, nullable=false)
	@OrderBy("asc")
	private String xacmlId = "urn";

	//bi-directional many-to-one association to Datatype
	@ManyToOne
	@JoinColumn(name="datatype")
	private Datatype datatypeBean;
	
	@Transient
	private String issuer = null;
	
	@Transient
	private boolean mustBePresent = false;

	@ManyToOne(optional = false)
	@JoinColumn(name="created_by")
	private UserInfo userCreatedBy;

	@ManyToOne(optional = false)
	@JoinColumn(name="modified_by")
	private UserInfo userModifiedBy;
	
	public UserInfo getUserCreatedBy() {
		return userCreatedBy;
	}

	public void setUserCreatedBy(UserInfo userCreatedBy) {
		this.userCreatedBy = userCreatedBy;
	}

	public UserInfo getUserModifiedBy() {
		return userModifiedBy;
	}

	public void setUserModifiedBy(UserInfo userModifiedBy) {
		this.userModifiedBy = userModifiedBy;
	}
	
	public DecisionSettings() {
	}
	
	public DecisionSettings(String domain) {
		this.xacmlId = domain;
	}
	
	public DecisionSettings(String domain, String user) {
		this(domain);
	}
	public DecisionSettings(DecisionSettings copy, String user) {
		this(copy.getXacmlId() + ":(0)", user);
		this.datatypeBean = copy.getDatatypeBean();
		this.description = copy.getDescription();
		
	}
	
	public String getDecisionSettings(){
		return this.xacmlId;
	}
	
	public String setDecisionSettings(){
		return this.xacmlId;
	}
	@PrePersist
	public void	prePersist() {
		Date date = new Date();
		this.createdDate = date;
		this.modifiedDate = date;
	}
	
	@PreUpdate
	public void preUpdate() {
		this.modifiedDate = new Date();
		try {
			this.userModifiedBy = XacmlAdminAuthorization.getUserId();;
		} catch (Exception e) {
			PolicyLogger.error(MessageCodes.EXCEPTION_ERROR, e, "DecisionSettings", "Exception caused While adding Modified by Role");
		}
	}

	public int getId() {
		return this.id;
	}

	public void setId(int id) {
		this.id = id;
	}

	
	public Date getCreatedDate() {
		return this.createdDate;
	}

	public void setCreatedDate(Date createdDate) {
		this.createdDate = createdDate;
	}

	public String getDescription() {
		return this.description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public Date getModifiedDate() {
		return this.modifiedDate;
	}

	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	public String getXacmlId() {
		return this.xacmlId;
	}
	
/*	@Transient
	public Identifier getXacmlIdentifier() {
		return new IdentifierImpl(this.xacmlId);
	}*/

	public void setXacmlId(String xacmlId) {
		this.xacmlId = xacmlId;
	}
	
	public Datatype getDatatypeBean() {
		return this.datatypeBean;
	}

	public void setDatatypeBean(Datatype datatypeBean) {
		this.datatypeBean = datatypeBean;
	}

	@Transient
	public String getIssuer() {
		return issuer;
	}

	@Transient
	public void setIssuer(String issuer) {
		this.issuer = issuer;
	}

	@Transient
	public boolean isMustBePresent() {
		return mustBePresent;
	}

	@Transient
	public void setMustBePresent(boolean mustBePresent) {
		this.mustBePresent = mustBePresent;
	}

	public String getPriority() {
		return priority;
	}

	public void setPriority(String priority) {
		this.priority = priority;
	}
}
	
